@@ -67,11 +67,6 @@
 #define MINIMUM_ON_SCREEN_WIDTH		100
 #define MINIMUM_ON_SCREEN_HEIGHT	100
 
-/* How far down the window tree will we search when looking for top-level
- * windows? Some window managers doubly-reparent the client, so account
- * for that, and add some slop.
- */
-#define MAXIMUM_WM_REPARENTING_DEPTH 4
 
 /**
  * eel_gtk_button_new_with_stock_icon:
@@ -261,9 +256,6 @@ eel_gtk_window_event_is_close_accelerator (GtkWindow *window, GdkEventKey *event
 		}
 	}
 
-	if (event->keyval == GDK_Escape) {
-		return TRUE;
-	}
 
 	return FALSE;	
 }
@@ -364,7 +356,9 @@ eel_gtk_window_set_initial_geometry (GtkWindow *window,
 					  guint width,
 					  guint height)
 {
+	GdkScreen *screen;
 	int real_left, real_top;
+	int screen_width, screen_height;
 
 	g_return_if_fail (GTK_IS_WINDOW (window));
 	g_return_if_fail (!(geometry_flags & EEL_GDK_WIDTH_VALUE) || width > 0);
@@ -380,6 +374,10 @@ eel_gtk_window_set_initial_geometry (GtkWindow *window,
 		real_left = left;
 		real_top = top;
 
+		screen = gtk_window_get_screen (window);
+		screen_width  = gdk_screen_get_width  (screen);
+		screen_height = gdk_screen_get_height (screen);
+
 		/* This is sub-optimal. GDK doesn't allow us to set win_gravity
 		 * to South/East types, which should be done if using negative
 		 * positions (so that the right or bottom edge of the window
@@ -387,10 +385,10 @@ eel_gtk_window_set_initial_geometry (GtkWindow *window,
 		 * However it does seem to be consistent with other GNOME apps.
 		 */
 		if (geometry_flags & EEL_GDK_X_NEGATIVE) {
-			real_left = gdk_screen_width () - real_left;
+			real_left = screen_width - real_left;
 		}
 		if (geometry_flags & EEL_GDK_Y_NEGATIVE) {
-			real_top = gdk_screen_height () - real_top;
+			real_top = screen_height - real_top;
 		}
 
 		sanity_check_window_position (&real_left, &real_top);
@@ -413,7 +411,7 @@ eel_gtk_window_set_initial_geometry (GtkWindow *window,
  * some sanity-checking on the passed-in values.
  * 
  * @window: A non-visible GtkWindow
- * @geometry_string: A string suitable for use with gnome_parse_geometry
+ * @geometry_string: A string suitable for use with eel_gdk_parse_geometry
  * @minimum_width: If the width from the string is smaller than this,
  * use this for the width.
  * @minimum_height: If the height from the string is smaller than this,
